@@ -14,21 +14,39 @@ add_action_impl <- function(x, action, name, ..., call = caller_env()) {
 }
 
 #' @export
-add_action_impl.action_pre <- function(x, action, name, ..., call = caller_env()) {
+add_action_impl.action_pre <- function(
+  x,
+  action,
+  name,
+  ...,
+  call = caller_env()
+) {
   check_singleton(x$pre$actions, name, call = call)
   x$pre <- add_action_to_stage(x$pre, action, name, order_stage_pre())
   x
 }
 
 #' @export
-add_action_impl.action_fit <- function(x, action, name, ..., call = caller_env()) {
+add_action_impl.action_fit <- function(
+  x,
+  action,
+  name,
+  ...,
+  call = caller_env()
+) {
   check_singleton(x$fit$actions, name, call = call)
   x$fit <- add_action_to_stage(x$fit, action, name, order_stage_fit())
   x
 }
 
 #' @export
-add_action_impl.action_post <- function(x, action, name, ..., call = caller_env()) {
+add_action_impl.action_post <- function(
+  x,
+  action,
+  name,
+  ...,
+  call = caller_env()
+) {
   check_singleton(x$post$actions, name, call = call)
   x$post <- add_action_to_stage(x$post, action, name, order_stage_post())
   x
@@ -49,7 +67,7 @@ order_stage_fit <- function() {
 }
 
 order_stage_post <- function() {
-  character()
+  "tailor"
 }
 
 # ------------------------------------------------------------------------------
