@@ -2,40 +2,36 @@
 #'
 #' @description
 #' This is a [generics::tidy()] method for a workflow that calls `tidy()` on
-#' either the underlying parsnip model or the recipe, depending on the value
+#' either the underlying parsnip model, recipe, or tailor, depending on the value
 #' of `what`.
 #'
-#' `x` must be a fitted workflow, resulting in fitted parsnip model or prepped
-#' recipe that you want to tidy.
+#' `x` must be a fitted workflow, resulting in fitted parsnip model, prepped
+#' recipe or fitted tailor that you want to tidy.
 #'
 #' @details
 #' To tidy the unprepped recipe, use [extract_preprocessor()] and `tidy()`
-#' that directly.
+#' that directly. To tidy the untrained tailor, use [extract_postprocessor()]
+#' and `tidy()` that directly.
 #'
 #' @param x A workflow
 #'
-#' @param what A single string. Either `"model"` or `"recipe"` to select
-#'   which part of the workflow to tidy. Defaults to tidying the model.
+#' @param what A single string. Either `"model"`, `"recipe"` or `"tailor"` to
+#' select which part of the workflow to tidy. Defaults to tidying the model.
 #'
 #' @param ... Arguments passed on to methods
 #'
 #' @export
 tidy.workflow <- function(x, what = "model", ...) {
-  what <- arg_match(what, values = c("model", "recipe"))
+  what <- arg_match(what, values = c("model", "recipe", "tailor"))
 
-  if (identical(what, "model")) {
-    x <- extract_fit_parsnip(x)
-    out <- tidy(x, ...)
-    return(out)
-  }
+  to_tidy <- switch(
+    what,
+    model = extract_fit_parsnip(x),
+    recipe = extract_recipe(x),
+    tailor = extract_tailor(x)
+  )
 
-  if (identical(what, "recipe")) {
-    x <- extract_recipe(x)
-    out <- tidy(x, ...)
-    return(out)
-  }
-
-  cli_abort("{.arg what} must be {.val model} or {.val recipe}.", .internal = TRUE)
+  tidy(to_tidy, ...)
 }
 
 # ------------------------------------------------------------------------------
@@ -63,11 +59,11 @@ tidy.workflow <- function(x, what = "model", ...) {
 #'
 #' data("attrition")
 #'
-#' model <- logistic_reg() %>%
+#' model <- logistic_reg() |>
 #'   set_engine("glm")
 #'
-#' wf <- workflow() %>%
-#'   add_model(model) %>%
+#' wf <- workflow() |>
+#'   add_model(model) |>
 #'   add_formula(
 #'     Attrition ~ BusinessTravel + YearsSinceLastPromotion + OverTime
 #'   )
@@ -123,11 +119,11 @@ glance.workflow <- function(x, ...) {
 #'
 #' data("attrition")
 #'
-#' model <- logistic_reg() %>%
+#' model <- logistic_reg() |>
 #'   set_engine("glm")
 #'
-#' wf <- workflow() %>%
-#'   add_model(model) %>%
+#' wf <- workflow() |>
+#'   add_model(model) |>
 #'   add_formula(
 #'     Attrition ~ BusinessTravel + YearsSinceLastPromotion + OverTime
 #'   )
@@ -148,7 +144,11 @@ augment.workflow <- function(x, new_data, eval_time = NULL, ...) {
   }
 
   # `augment.model_fit()` requires the pre-processed `new_data`
-  forged <- hardhat::forge(new_data, blueprint = mold$blueprint, outcomes = outcomes)
+  forged <- hardhat::forge(
+    new_data,
+    blueprint = mold$blueprint,
+    outcomes = outcomes
+  )
 
   if (outcomes) {
     new_data_forged <- vctrs::vec_cbind(forged$predictors, forged$outcomes)
@@ -159,6 +159,11 @@ augment.workflow <- function(x, new_data, eval_time = NULL, ...) {
   new_data_forged <- prepare_augment_new_data(new_data_forged)
   out <- augment(fit, new_data_forged, eval_time = eval_time, ...)
 
+  if (has_postprocessor(x)) {
+    post <- extract_postprocessor(x, estimated = TRUE)
+    out <- predict(post, new_data = out)
+  }
+
   augment_columns <- setdiff(
     names(out),
     names(new_data_forged)
