@@ -32,6 +32,8 @@
 #'   (or their sum if `summarize = TRUE`) and do not include other portions of
 #'   the elapsed time in [workflows::fit.workflow()].
 #'
+#' - `extract_postprocessor()` returns the postprocessor object.
+#'
 #' @param x A workflow
 #'
 #' @param estimated A logical for whether the original (unfit) recipe or the
@@ -53,14 +55,14 @@
 #'
 #' *Good*:
 #' ```r
-#' workflow_fit %>% predict(new_data)
+#' workflow_fit |> predict(new_data)
 #' ```
 #'
 #' *Bad*:
 #' ```r
-#' workflow_fit %>% extract_fit_engine()  %>% predict(new_data)
+#' workflow_fit |> extract_fit_engine()  |> predict(new_data)
 #' # or
-#' workflow_fit %>% extract_fit_parsnip() %>% predict(new_data)
+#' workflow_fit |> extract_fit_parsnip() |> predict(new_data)
 #' ```
 #'
 #' @return
@@ -73,13 +75,13 @@
 #' library(recipes)
 #' library(magrittr)
 #'
-#' model <- linear_reg() %>%
+#' model <- linear_reg() |>
 #'   set_engine("lm")
 #'
-#' recipe <- recipe(mpg ~ cyl + disp, mtcars) %>%
+#' recipe <- recipe(mpg ~ cyl + disp, mtcars) |>
 #'   step_log(disp)
 #'
-#' base_wf <- workflow() %>%
+#' base_wf <- workflow() |>
 #'   add_model(model)
 #'
 #' recipe_wf <- add_recipe(base_wf, recipe)
@@ -130,7 +132,9 @@ extract_spec_parsnip.workflow <- function(x, ...) {
 extract_recipe.workflow <- function(x, ..., estimated = TRUE) {
   check_dots_empty()
   if (!is_bool(estimated)) {
-    cli_abort("{.arg estimated} must be a single {.code TRUE} or {.code FALSE}.")
+    cli_abort(
+      "{.arg estimated} must be a single {.code TRUE} or {.code FALSE}."
+    )
   }
   if (!has_preprocessor_recipe(x)) {
     cli_abort("The workflow must have a recipe preprocessor.")
@@ -191,6 +195,45 @@ extract_preprocessor.workflow <- function(x, ...) {
   cli_abort("The workflow does not have a preprocessor.")
 }
 
+#' @rdname extract-workflow
+#' @export
+extract_postprocessor.workflow <- function(x, ..., estimated = FALSE) {
+  if (has_postprocessor_tailor(x)) {
+    return(extract_tailor(x, estimated = estimated))
+  }
+
+  cli_abort("The workflow does not have a postprocessor.")
+}
+
+#' @export
+#' @rdname extract-workflow
+extract_tailor.workflow <- function(x, ..., estimated = TRUE) {
+  check_dots_empty()
+
+  if (!is_bool(estimated)) {
+    cli_abort(
+      "{.arg estimated} must be a single {.code TRUE} or {.code FALSE}."
+    )
+  }
+  if (!has_postprocessor_tailor(x)) {
+    cli_abort("The workflow must have a tailor postprocessor.")
+  }
+
+  if (estimated) {
+    res <- x$post$fit
+    if (is.null(res)) {
+      cli_abort(c(
+        "The workflow has a tailor postprocessor, but it has not been fit yet.",
+        i = "Do you need to call {.fun fit}?"
+      ))
+    }
+  } else {
+    res <- x$post$actions$tailor$tailor
+  }
+
+  res
+}
+
 #' @export
 #' @rdname extract-workflow
 extract_parameter_set_dials.workflow <- function(x, ...) {
@@ -204,6 +247,13 @@ extract_parameter_set_dials.workflow <- function(x, ...) {
     param_data <- vctrs::vec_rbind(param_data, recipe_param_data)
   }
 
+  if (has_postprocessor_tailor(x)) {
+    tailor <- extract_postprocessor(x)
+    tailor_param_data <- extract_parameter_set_dials(tailor)
+
+    param_data <- vctrs::vec_rbind(param_data, tailor_param_data)
+  }
+
   dials::parameters_constr(
     param_data$name,
     param_data$id,
