@@ -60,7 +60,10 @@
 #' update_model(fitted, regularized_model)
 add_model <- function(x, spec, ..., formula = NULL) {
   check_dots_empty()
+
   action <- new_action_model(spec, formula)
+  validate_compatibility_model(x, spec)
+
   add_action(x, action, "model")
 }
 
@@ -131,7 +134,13 @@ fit_from_xy <- function(spec, mold, case_weights, control_parsnip) {
   )
 }
 
-fit_from_formula <- function(spec, mold, case_weights, control_parsnip, formula) {
+fit_from_formula <- function(
+  spec,
+  mold,
+  case_weights,
+  control_parsnip,
+  formula
+) {
   data <- cbind(mold$outcomes, mold$predictors)
 
   fit(
@@ -187,8 +196,8 @@ new_action_model <- function(spec, formula, ..., call = caller_env()) {
   if (is_string(mode, string = "unknown")) {
     message <-
       c(
-      "{.arg spec} must have a known mode.",
-      i = "Set the mode of `spec` by using {.fun parsnip::set_mode} or by setting
+        "{.arg spec} must have a known mode.",
+        i = "Set the mode of `spec` by using {.fun parsnip::set_mode} or by setting
            the mode directly in the parsnip specification function."
       )
 
@@ -209,3 +218,22 @@ new_action_model <- function(spec, formula, ..., call = caller_env()) {
 
   new_action_fit(spec = spec, formula = formula, subclass = "action_model")
 }
+
+validate_compatibility_model <- function(x, spec, call = caller_env()) {
+  validate_is_workflow(x, call = call)
+
+  if (!has_postprocessor(x)) {
+    return(invisible(x))
+  }
+
+  post <- extract_postprocessor(x)
+
+  if (is_tailor(post)) {
+    validate_compatibility_model_tailor(
+      spec,
+      post,
+      call = call
+    )
+  }
+  invisible(x)
+}
