@@ -1,26 +1,29 @@
 #' Fit a workflow object
 #'
 #' @description
-#' Fitting a workflow currently involves two main steps:
+#' Fitting a workflow currently involves three main steps:
 #'
 #' - Preprocessing the data using a formula preprocessor, or by calling
 #'   [recipes::prep()] on a recipe.
 #'
 #' - Fitting the underlying parsnip model using [parsnip::fit.model_spec()].
 #'
-#' @details
-#' In the future, there will also be _postprocessing_ steps that can be added
-#' after the model has been fit.
+#' - Postprocessing predictions from the model using
+#'   [tailor::tailor()].
 #'
 #' @includeRmd man/rmd/indicators.Rmd details
 #'
 #' @param object A workflow
 #'
 #' @param data A data frame of predictors and outcomes to use when fitting the
-#'   workflow
+#'   preprocessor and model.
 #'
 #' @param ... Not used
 #'
+#' @param data_calibration A data frame of predictors and outcomes to use when
+#'   fitting the postprocessor. See the "Data Usage" section of [add_tailor()]
+#'   for more information.
+#'
 #' @param control A [control_workflow()] object
 #'
 #' @return
@@ -34,31 +37,39 @@
 #' library(recipes)
 #' library(magrittr)
 #'
-#' model <- linear_reg() %>%
+#' model <- linear_reg() |>
 #'   set_engine("lm")
 #'
-#' base_wf <- workflow() %>%
+#' base_wf <- workflow() |>
 #'   add_model(model)
 #'
-#' formula_wf <- base_wf %>%
+#' formula_wf <- base_wf |>
 #'   add_formula(mpg ~ cyl + log(disp))
 #'
 #' fit(formula_wf, mtcars)
 #'
-#' recipe <- recipe(mpg ~ cyl + disp, mtcars) %>%
+#' recipe <- recipe(mpg ~ cyl + disp, mtcars) |>
 #'   step_log(disp)
 #'
-#' recipe_wf <- base_wf %>%
+#' recipe_wf <- base_wf |>
 #'   add_recipe(recipe)
 #'
 #' fit(recipe_wf, mtcars)
-fit.workflow <- function(object, data, ..., control = control_workflow()) {
+fit.workflow <- function(
+  object,
+  data,
+  ...,
+  data_calibration = NULL,
+  control = control_workflow()
+) {
   check_dots_empty()
 
   if (is_missing(data)) {
     cli_abort("{.arg data} must be provided to fit a workflow.")
   }
 
+  validate_has_data_calibration(object, data_calibration)
+
   if (is_sparse_matrix(data)) {
     data <- sparsevctrs::coerce_to_sparse_tibble(
       data,
@@ -71,18 +82,42 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
   workflow <- object
   workflow <- .fit_pre(workflow, data)
   workflow <- .fit_model(workflow, control)
+
+  if (!.workflow_postprocessor_requires_fit(workflow)) {
+    # in this case, training the tailor on `data` will not leak data (#262)
+    data_calibration <- data
+  }
+  if (has_postprocessor(workflow)) {
+    workflow <- .fit_post(workflow, data_calibration)
+  }
+
   workflow <- .fit_finalize(workflow)
 
-  # TODO: Post-processing before `.fit_finalize()`?
-
   workflow
 }
 
+#' @export
+#' @rdname workflows-internals
+#' @keywords internal
+.workflow_postprocessor_requires_fit <- function(workflow) {
+  if (!has_postprocessor(workflow)) {
+    return(FALSE)
+  }
+  if (has_postprocessor_tailor(workflow)) {
+    requires_fit <- tailor::tailor_requires_fit(
+      extract_postprocessor(workflow, estimated = FALSE)
+    )
+  } else {
+    requires_fit <- FALSE
+  }
+  requires_fit
+}
+
 # ------------------------------------------------------------------------------
 
 #' Internal workflow functions
 #'
-#' `.fit_pre()`, `.fit_model()`, and `.fit_finalize()` are internal workflow
+#' `.fit_pre()`, `.fit_model()`, `.fit_post()` and `.fit_finalize()` are internal workflow
 #' functions for _partially_ fitting a workflow object. They are only exported
 #' for usage by the tuning package, [tune](https://github.com/tidymodels/tune),
 #' and the general user should never need to worry about them.
@@ -94,8 +129,12 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
 #'   For `.fit_model()`, this should be a workflow that has already been trained
 #'   through `.fit_pre()`.
 #'
+#'   For `.fit_post()`, this should be a workflow that has already been trained
+#'   through `.fit_pre()` and `.fit_model()`.
+#'
 #'   For `.fit_finalize()`, this should be a workflow that has been through
-#'   both `.fit_pre()` and `.fit_model()`.
+#'   both `.fit_pre()` and `.fit_model()`. If the workflow contains an optional
+#'   postprocessor, it should also have been trained through `.fit_post()`.
 #'
 #' @param data A data frame of predictors and outcomes to use when fitting the
 #'   workflow
@@ -110,11 +149,11 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
 #' library(recipes)
 #' library(magrittr)
 #'
-#' model <- linear_reg() %>%
+#' model <- linear_reg() |>
 #'   set_engine("lm")
 #'
-#' wf_unfit <- workflow() %>%
-#'   add_model(model) %>%
+#' wf_unfit <- workflow() |>
+#'   add_model(model) |>
 #'   add_formula(mpg ~ cyl + log(disp))
 #'
 #' wf_fit_pre <- .fit_pre(wf_unfit, mtcars)
@@ -162,6 +201,13 @@ fit.workflow <- function(object, data, ..., control = control_workflow()) {
   fit(action_model, workflow = workflow, control = control)
 }
 
+#' @rdname workflows-internals
+#' @export
+.fit_post <- function(workflow, data) {
+  action_post <- workflow[["post"]][["actions"]][[1]]
+  fit(action_post, workflow = workflow, data = data)
+}
+
 #' @rdname workflows-internals
 #' @export
 .fit_finalize <- function(workflow) {
@@ -175,8 +221,8 @@ validate_has_preprocessor <- function(x, ..., call = caller_env()) {
 
   has_preprocessor <-
     has_preprocessor_formula(x) ||
-      has_preprocessor_recipe(x) ||
-      has_preprocessor_variables(x)
+    has_preprocessor_recipe(x) ||
+    has_preprocessor_variables(x)
 
   if (!has_preprocessor) {
     message <- c(
@@ -206,6 +252,30 @@ validate_has_model <- function(x, ..., call = caller_env()) {
   invisible(x)
 }
 
+validate_has_data_calibration <- function(
+  x,
+  data_calibration,
+  call = caller_env()
+) {
+  if (.workflow_postprocessor_requires_fit(x) && is.null(data_calibration)) {
+    cli::cli_abort(
+      "The workflow requires {.arg data_calibration} to train but none
+       was supplied.",
+      call = call
+    )
+  }
+
+  if (!.workflow_postprocessor_requires_fit(x) && !is.null(data_calibration)) {
+    cli::cli_warn(
+      "The workflow does not require {.arg data_calibration} to train
+       but it was supplied.",
+      call = call
+    )
+  }
+
+  invisible(x)
+}
+
 # ------------------------------------------------------------------------------
 
 finalize_blueprint <- function(workflow) {
