@@ -33,13 +33,13 @@
 #' training <- mtcars[1:20, ]
 #' testing <- mtcars[21:32, ]
 #'
-#' model <- linear_reg() %>%
+#' model <- linear_reg() |>
 #'   set_engine("lm")
 #'
-#' workflow <- workflow() %>%
+#' workflow <- workflow() |>
 #'   add_model(model)
 #'
-#' recipe <- recipe(mpg ~ cyl + disp, training) %>%
+#' recipe <- recipe(mpg ~ cyl + disp, training) |>
 #'   step_log(disp)
 #'
 #' workflow <- add_recipe(workflow, recipe)
@@ -49,7 +49,13 @@
 #' # This will automatically `bake()` the recipe on `testing`,
 #' # applying the log step to `disp`, and then fit the regression.
 #' predict(fit_workflow, testing)
-predict.workflow <- function(object, new_data, type = NULL, opts = list(), ...) {
+predict.workflow <- function(
+  object,
+  new_data,
+  type = NULL,
+  opts = list(),
+  ...
+) {
   workflow <- object
 
   if (!is_trained_workflow(workflow)) {
@@ -69,7 +75,15 @@ predict.workflow <- function(object, new_data, type = NULL, opts = list(), ...)
   fit <- extract_fit_parsnip(workflow)
   new_data <- forge_predictors(new_data, workflow)
 
-  predict(fit, new_data, type = type, opts = opts, ...)
+  if (!has_postprocessor(workflow)) {
+    return(predict(fit, new_data, type = type, opts = opts, ...))
+  }
+
+  # use `augment()` rather than `predict()` to get all possible prediction `type`s (#234).
+  pred_model <- augment(fit, new_data, opts = opts, ...)
+
+  post <- extract_postprocessor(workflow, estimated = TRUE)
+  predict(post, pred_model)[predict_type_column_names(type, post$columns)]
 }
 
 forge_predictors <- function(new_data, workflow) {
@@ -77,3 +91,26 @@ forge_predictors <- function(new_data, workflow) {
   forged <- hardhat::forge(new_data, blueprint = mold$blueprint)
   forged$predictors
 }
+
+predict_type_column_names <- function(
+  type,
+  tailor_columns,
+  call = caller_env()
+) {
+  check_string(type, allow_null = TRUE, call = call)
+
+  if (is.null(type)) {
+    return(tailor_columns$estimate)
+  }
+
+  switch(
+    type,
+    numeric = ,
+    class = tailor_columns$estimate,
+    prob = tailor_columns$probabilities,
+    cli::cli_abort(
+      "Unsupported prediction {.arg type} {.val {type}} for a workflow with a postprocessor.",
+      call = call
+    )
+  )
+}
