@@ -37,13 +37,13 @@
 #' library(recipes)
 #' library(magrittr)
 #'
-#' model <- linear_reg() %>%
+#' model <- linear_reg() |>
 #'   set_engine("lm")
 #'
-#' recipe <- recipe(mpg ~ cyl + disp, mtcars) %>%
+#' recipe <- recipe(mpg ~ cyl + disp, mtcars) |>
 #'   step_log(disp)
 #'
-#' base_wf <- workflow() %>%
+#' base_wf <- workflow() |>
 #'   add_model(model)
 #'
 #' recipe_wf <- add_recipe(base_wf, recipe)
@@ -82,7 +82,11 @@ NULL
 #' @rdname workflow-extractors
 #' @export
 pull_workflow_preprocessor <- function(x) {
-  lifecycle::deprecate_warn("0.2.3", "pull_workflow_preprocessor()", "extract_preprocessor()")
+  lifecycle::deprecate_warn(
+    "0.2.3",
+    "pull_workflow_preprocessor()",
+    "extract_preprocessor()"
+  )
   validate_is_workflow(x)
   extract_preprocessor(x)
 }
@@ -90,7 +94,11 @@ pull_workflow_preprocessor <- function(x) {
 #' @rdname workflow-extractors
 #' @export
 pull_workflow_spec <- function(x) {
-  lifecycle::deprecate_warn("0.2.3", "pull_workflow_spec()", "extract_spec_parsnip()")
+  lifecycle::deprecate_warn(
+    "0.2.3",
+    "pull_workflow_spec()",
+    "extract_spec_parsnip()"
+  )
   validate_is_workflow(x)
   extract_spec_parsnip(x)
 }
@@ -98,7 +106,11 @@ pull_workflow_spec <- function(x) {
 #' @rdname workflow-extractors
 #' @export
 pull_workflow_fit <- function(x) {
-  lifecycle::deprecate_warn("0.2.3", "pull_workflow_fit()", "extract_fit_parsnip()")
+  lifecycle::deprecate_warn(
+    "0.2.3",
+    "pull_workflow_fit()",
+    "extract_fit_parsnip()"
+  )
   validate_is_workflow(x)
   extract_fit_parsnip(x)
 }
@@ -114,7 +126,11 @@ pull_workflow_mold <- function(x) {
 #' @rdname workflow-extractors
 #' @export
 pull_workflow_prepped_recipe <- function(x) {
-  lifecycle::deprecate_warn("0.2.3", "pull_workflow_prepped_recipe()", "extract_recipe()")
+  lifecycle::deprecate_warn(
+    "0.2.3",
+    "pull_workflow_prepped_recipe()",
+    "extract_recipe()"
+  )
   validate_is_workflow(x)
   extract_recipe(x)
 }
