@@ -22,6 +22,14 @@ hardhat::extract_mold
 #' @export
 hardhat::extract_preprocessor
 #'
+#' @importFrom hardhat extract_postprocessor
+#' @export
+hardhat::extract_postprocessor
+#'
+#' @importFrom hardhat extract_tailor
+#' @export
+hardhat::extract_tailor
+#'
 #' @importFrom hardhat extract_parameter_set_dials
 #' @export
 hardhat::extract_parameter_set_dials
