@@ -1,4 +1,8 @@
-new_stage_pre <- function(actions = new_named_list(), mold = NULL, case_weights = NULL) {
+new_stage_pre <- function(
+  actions = new_named_list(),
+  mold = NULL,
+  case_weights = NULL
+) {
   if (!is.null(mold) && !is.list(mold)) {
     cli_abort(
       "{.arg mold} must be a result of calling {.fun hardhat::mold}.",
@@ -29,8 +33,12 @@ new_stage_fit <- function(actions = new_named_list(), fit = NULL) {
   new_stage(actions = actions, fit = fit, subclass = "stage_fit")
 }
 
-new_stage_post <- function(actions = new_named_list()) {
-  new_stage(actions, subclass = "stage_post")
+new_stage_post <- function(actions = new_named_list(), fit = NULL) {
+  if (!is.null(fit) && !is_postprocessor(fit)) {
+    cli_abort("{.arg fit} must be a trained post-processor.", .internal = TRUE)
+  }
+
+  new_stage(actions, fit = fit, subclass = "stage_post")
 }
 
 # ------------------------------------------------------------------------------
@@ -42,9 +50,7 @@ new_stage_post <- function(actions = new_named_list()) {
 # - fit
 # - post
 
-new_stage <- function(actions = new_named_list(),
-                      ...,
-                      subclass = character()) {
+new_stage <- function(actions = new_named_list(), ..., subclass = character()) {
   if (!is_list_of_actions(actions)) {
     cli_abort("{.arg actions} must be a list of actions.", .internal = TRUE)
   }
