@@ -14,6 +14,10 @@ is_model_spec <- function(x) {
   inherits(x, "model_spec") || modelenv::is_unsupervised_spec(x)
 }
 
+is_postprocessor <- function(x) {
+  is_tailor(x)
+}
+
 validate_recipes_available <- function(..., call = caller_env()) {
   check_dots_empty()
 
@@ -27,6 +31,19 @@ validate_recipes_available <- function(..., call = caller_env()) {
   invisible()
 }
 
+validate_tailor_available <- function(..., call = caller_env()) {
+  check_dots_empty()
+
+  if (!requireNamespace("tailor", quietly = TRUE)) {
+    cli_abort(
+      "The {.pkg tailor} package must be available to add a tailor.",
+      call = call
+    )
+  }
+
+  invisible()
+}
+
 # ------------------------------------------------------------------------------
 
 # https://github.com/r-lib/tidyselect/blob/10e00cea2fff3585fc827b6a7eb5e172acadbb2f/R/utils.R#L109
@@ -87,6 +104,14 @@ has_fit <- function(x) {
   !is.null(x$fit$fit)
 }
 
+has_postprocessor <- function(x) {
+  has_postprocessor_tailor(x)
+}
+
+has_postprocessor_tailor <- function(x) {
+  "tailor" %in% names(x$post$actions)
+}
+
 has_blueprint <- function(x) {
   if (has_preprocessor_formula(x)) {
     !is.null(x$pre$actions$formula$blueprint)
