@@ -87,6 +87,30 @@ test_that("cannot fit without a fit stage", {
   })
 })
 
+test_that("fit.workflow confirms compatibility of object and calibration", {
+  skip_if_not_installed("tailor")
+  skip_if_not_installed("probably")
+
+  mod <- parsnip::linear_reg()
+  mod <- parsnip::set_engine(mod, "lm")
+
+  workflow <- workflow()
+  workflow <- add_formula(workflow, mpg ~ cyl)
+  workflow <- add_model(workflow, mod)
+
+  expect_snapshot(
+    res <- fit(workflow, mtcars, data_calibration = mtcars)
+  )
+
+  tailor <- tailor::tailor()
+  tailor <- tailor::adjust_numeric_calibration(tailor)
+  workflow <- add_tailor(workflow, tailor)
+
+  expect_snapshot(error = TRUE, {
+    fit(workflow, mtcars)
+  })
+})
+
 # ------------------------------------------------------------------------------
 # .fit_pre()
 
@@ -174,6 +198,57 @@ test_that("`.fit_pre()` doesn't modify user supplied recipe blueprint", {
   expect_identical(result$pre$actions$recipe$blueprint, blueprint)
 })
 
+# ------------------------------------------------------------------------------
+# .fit_post()
+test_that(".workflow_postprocessor_requires_fit works", {
+  skip_if_not_installed("tailor")
+  skip_if_not_installed("probably")
+
+  expect_false(.workflow_postprocessor_requires_fit(workflow()))
+  expect_false(.workflow_postprocessor_requires_fit(
+    workflow() |> add_model(parsnip::linear_reg())
+  ))
+  expect_false(.workflow_postprocessor_requires_fit(
+    workflow() |> add_formula(mpg ~ .)
+  ))
+  expect_false(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_formula(mpg ~ .) |>
+      add_model(parsnip::linear_reg())
+  ))
+  expect_false(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_tailor(tailor::tailor())
+  ))
+  expect_false(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_tailor(tailor::tailor() |> tailor::adjust_probability_threshold(.4))
+  ))
+
+  expect_true(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_tailor(tailor::tailor() |> tailor::adjust_numeric_calibration())
+  ))
+  expect_true(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_tailor(
+        tailor::tailor() |>
+          tailor::adjust_numeric_calibration() |>
+          tailor::adjust_numeric_range(lower_limit = 1)
+      )
+  ))
+  expect_true(.workflow_postprocessor_requires_fit(
+    workflow() |>
+      add_formula(mpg ~ .) |>
+      add_model(parsnip::linear_reg()) |>
+      add_tailor(
+        tailor::tailor() |>
+          tailor::adjust_numeric_calibration() |>
+          tailor::adjust_numeric_range(lower_limit = 1)
+      )
+  ))
+})
+
 # ------------------------------------------------------------------------------
 # .fit_finalize()
 
