@@ -81,3 +81,13 @@ test_that("can print workflow with case weights, preprocessor, and model", {
 
   expect_snapshot(workflow)
 })
+
+test_that("can print workflow with postprocessor", {
+  skip_if_not_installed("tailor")
+
+  post <- tailor::tailor()
+  workflow <- workflow()
+  workflow <- add_postprocessor(workflow, post)
+
+  expect_snapshot(workflow)
+})
